==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "Kapabligita",
    "Wrong password" : "Malĝusta pasvorto",
    "Saved" : "Konservita",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Authentication error" : "Aŭtentiga eraro",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Motoro ne subtenas ŝanĝi pasvorton, sed la ĉifroŝlosilo de la uzanto sukcese ĝisdatiĝis.",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Group already exists." : "Grupo jam ekzistas",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Invalid request" : "Nevalida peto",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Email saved" : "La retpoŝtadreso konserviĝis",
    "Admins can't remove themself from the admin group" : "Administrantoj ne povas forigi sin mem el la administra grupo.",
    "Unable to add user to group %s" : "Ne eblis aldoni la uzanton al la grupo %s",
    "Unable to remove user from group %s" : "Ne eblis forigi la uzantan el la grupo %s",
    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
    "Sending..." : "Sendante...",
    "All" : "Ĉio",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enable" : "Kapabligi",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updating...." : "Ĝisdatigata...",
    "Error while updating app" : "Eraris ĝisdatigo de la aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "Uninstalling ...." : "Malinstalante...",
    "Error while uninstalling app" : "Eraris malinstalo de aplikaĵo",
    "Uninstall" : "Malinstali",
    "Delete" : "Forigi",
    "Select a profile picture" : "Elekti profilan bildon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Groups" : "Grupoj",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "__language_name__" : "Esperanto",
    "Unlimited" : "Senlima",
    "Personal info" : "Persona informo",
    "Sync clients" : "Sinkronigi klientojn",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "Email server" : "Retpoŝtoservilo",
    "Open documentation" : "Malfermi la dokumentaron",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Cron" : "Cron",
    "Version" : "Eldono",
    "Sharing" : "Kunhavigo",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "User documentation" : "Uzodokumentaro",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Email" : "Retpoŝto",
    "Your email address" : "Via retpoŝta adreso",
    "Password" : "Pasvorto",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "Language" : "Lingvo",
    "Help translate" : "Helpu traduki",
    "Get the apps to sync your files" : "Ekhavu la aplikaĵojn por sinkronigi viajn dosierojn",
    "Desktop client" : "Labortabla kliento",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Name" : "Nomo",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Show last log in" : "Montri lastan ensaluton",
    "Show user backend" : "Montri uzantomotoron",
    "E-Mail" : "Retpoŝtadreso",
    "Create" : "Krei",
    "Everyone" : "Ĉiuj",
    "Admins" : "Administrantoj",
    "Other" : "Alia",
    "Quota" : "Kvoto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta",
    "Language changed" : "La lingvo estas ŝanĝita",
    "Please wait...." : "Bonvolu atendi...",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Ĉio (fatalaĵoj, eraroj, avertoj, informoj, sencimigaj mesaĝoj)",
    "Info, warnings, errors and fatal issues" : "Informoj, avertoj, eraroj kaj fatalaĵoj",
    "Warnings, errors and fatal issues" : "Avertoj, eraroj kaj fatalaĵoj",
    "Errors and fatal issues" : "Eraroj kaj fatalaĵoj",
    "Fatal issues only" : "Fatalaĵoj nur",
    "Log" : "Protokolo",
    "What to log" : "Kion protokoli",
    "Download logfile" : "Elŝuti protokoldosiero",
    "More" : "Pli",
    "Less" : "Malpli",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite uziĝas kiel datumbazo. Por pli grandaj instaloj ni rekomendas ŝanĝi ĝin per malsama datumbazomotoro.",
    "Uninstall App" : "Malinstali aplikaĵon",
    "Group" : "Grupo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/eo.js <==
OC.L10N.register(
    "settings",
    {
    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
    "Wrong password" : "Malĝusta pasvorto",
    "Saved" : "Konservita",
    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
    "Authentication error" : "Aŭtentiga eraro",
    "Federated Cloud Sharing" : "Federnuba kunhavado",
    "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
    "Your username is: %s" : "Via uzantnomo estas\\: %s",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Delete" : "Forigi",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Select a profile picture" : "Elekti profilan bildon",
    "Groups" : "Grupoj",
    "Official" : "Oficiala",
    "User documentation" : "Uzodokumentaro",
    "Disable all" : "Malkapabligi ĉiu",
    "Enable all" : "Kapabligi ĉiu",
    "Download and enable" : "Elŝuti kaj kapabligi",
    "Enable" : "Kapabligi",
    "Settings" : "Agordo",
    "You do not have permissions to see the details of this user" : "Vi ne permesatas vidi la detalojn de ĉi tiu uzanto",
    "Delete user" : "Forigita uzanto",
    "Disable user" : "Malkapabligi uzanto",
    "Enable user" : "Kapabligi uzanto",
    "Email" : "Retpoŝto",
    "Language" : "Lingvo",
    "User backend" : "Uzantomotoro",
    "Unlimited" : "Senlima",
    "Default quota" : "Defaŭlta kvoto",
    "Default language" : "Defaŭlta lingvo",
    "Common languages" : "Komunaj lingvoj",
    "All languages" : "Ĉiuj lingvoj",
    "App update" : "Aplikaĵon ĝisdatigi",
    "Your apps" : "Viaj aplikaĵoj",
    "Active apps" : "Kapabligitaj aplikaĵoj",
    "Disabled apps" : "Malkapabligitaj aplikaĵoj",
    "Updates" : "Ĝisdatigoj",
    "Admins" : "Administrantoj",
    "Everyone" : "Ĉiuj",
    "New user" : "Nova uzanto",
    "Common Name" : "Komuna nomo",
    "Valid until" : "Valida ĝis",
    "Valid until %s" : "Valida ĝis %s",
    "Administrator documentation" : "Administrodokumentaro",
    "Forum" : "Forumo",
    "Commercial support" : "Komerca subteno",
    "None" : "Nenio",
    "Login" : "Ensaluti",
    "Email server" : "Retpoŝtoservilo",
    "Open documentation" : "Malfermi la dokumentaron",
    "Send mode" : "Sendi pli",
    "Encryption" : "Ĉifrado",
    "From address" : "El adreso",
    "mail" : "retpoŝto",
    "Authentication method" : "Aŭtentiga metodo",
    "Authentication required" : "Aŭtentiĝo nepras",
    "Server address" : "Servila adreso",
    "Port" : "Pordo",
    "Credentials" : "Aŭtentigiloj",
    "SMTP Username" : "SMTP-uzantonomo",
    "SMTP Password" : "SMTP-pasvorto",
    "Test email settings" : "Provi retpoŝtagordon",
    "Send email" : "Sendi retpoŝton",
    "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas kapabligi ĉifradon?",
    "Enable encryption" : "Kapabligi ĉifradon",
    "Version" : "Eldono",
    "Sharing" : "Kunhavigo",
    "Allow apps to use the Share API" : "Kapabligi aplikaĵojn uzi la API-on pri Kunhavigo",
    "Allow users to share via link" : "Permesi uzantojn kunhavigi ligile",
    "Allow public uploads" : "Permesi publikajn alŝutojn",
    "Expire after " : "Eksvalidigi post",
    "days" : "tagoj",
    "Allow resharing" : "Kapabligi rekunhavigon",
    "Profile picture" : "Profila bildo",
    "Upload new" : "Alŝuti novan",
    "Select from Files" : "Elekti el Dosieroj",
    "Remove image" : "Forigi bildon",
    "Cancel" : "Nuligi",
    "Full name" : "Plena nomo",
    "Your email address" : "Via retpoŝta adreso",
    "Help translate" : "Helpu traduki",
    "Password" : "Pasvorto",
    "Current password" : "Nuna pasvorto",
    "New password" : "Nova pasvorto",
    "Change password" : "Ŝanĝi la pasvorton",
    "App name" : "Namo de aplikaĵo",
    "Username" : "Uzantonomo",
    "Done" : "Farita",
    "Enabled apps" : "Kapabligitaj aplikaĵoj",
    "Group already exists." : "Grupo jam ekzistas",
    "Your full name has been changed." : "Via plena nomo ŝanĝitas.",
    "Email saved" : "La retpoŝtadreso konserviĝis",
    "All" : "Ĉio",
    "Disabling app …" : "Malkapabligas aplikaĵon …",
    "Error while disabling app" : "Eraris malkapabligo de aplikaĵo",
    "Disable" : "Malkapabligi",
    "Enabling app …" : "Kapabligas aplikaĵon …",
    "Error while enabling app" : "Eraris kapabligo de aplikaĵo",
    "Updated" : "Ĝisdatigita",
    "deleted {groupName}" : "{groupName} foriĝis",
    "undo" : "malfari",
    "never" : "neniam",
    "deleted {userName}" : "{userName} foriĝis",
    "Unable to add user to group {group}" : "Ne eblis aldoni la uzanton al la grupo {group}",
    "Unable to remove user from group {group}" : "Ne eblis forigi la uzantan el la grupo {group}",
    "A valid username must be provided" : "Valida uzantonomo devas proviziĝi",
    "Error creating user: {message}" : "Erariz kreiĝi uzanto: {message}",
    "A valid password must be provided" : "Valida pasvorto devas proviziĝi",
    "by %s" : "de %s",
    "%s-licensed" : "%s-permesila",
    "Documentation:" : "Dokumentaro:",
    "Admin documentation" : "Administrodokumentaro",
    "Show description …" : "Montri priskribon...",
    "Hide description …" : "Malmontri priskribon...",
    "Enable only for specific groups" : "Kapabligi nur por specifajn grupojn",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "App passwords" : "Aplikaĵaj pasvortoj",
    "Show user backend" : "Montri uzantomotoron",
    "Send email to new user" : "Sendi retmesaĝon al nova uzanto",
    "E-Mail" : "Retpoŝtadreso",
    "Create" : "Krei",
    "Group name" : "Gruponomo",
    "Disabled" : "Malkapabligita",
    "Other" : "Alia",
    "Quota" : "Kvoto",
    "change full name" : "ŝanĝi plenan nomon",
    "set new password" : "agordi novan pasvorton",
    "change email address" : "ŝanĝi retpoŝtadreson",
    "Default" : "Defaŭlta",
    "Updating …" : "Ĝisdatigatas …",
    "Could not update app" : "Ne eblis ĝisdatigi la aplikaĵon."
},
"nplurals=2; plural=(n != 1);");
